pub trait Split<Target> {
type Remainder;
// Required method
fn split(self) -> (Target, Self::Remainder);
}Expand description
Compile time splitting of heterogeneous lists.
Allows splitting a heterogeneous list at a certain point, determined by the Target type,
which should match this list type until a certain element. The list after that point is
returned as the Remainder type.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".